@@ -30,7 +30,7 @@ import java.util.*;
  * <code>StringConcatenator</code>NX̋@\NXB
  *
  * @author  V. 
- * @version $Revision: 1.2 $, $Date: 2007/02/15 15:28:05 $
+ * @version $Revision: 1.3 $, $Date: 2007/05/27 16:13:17 $
  */
 public class StringConcatenatorTest extends FunctionTester
 {
@@ -271,6 +271,7 @@ public class StringConcatenatorTest extends FunctionTester
     EQUAL(StringConcatenator.concatenate(new ArrayList<String>(0), ","), "");
   }
 
+  @Deprecated
   public void repeat_repeated_count()
   {
     MSG("ʏ̏ꍇ");
@@ -281,6 +282,7 @@ public class StringConcatenatorTest extends FunctionTester
     EQUAL(StringConcatenator.repeat('a', 4), "aaaa");
   }
 
+  @Deprecated
   public void repeat_repeated_count_1()
   {
     MSG("Jԉ񐔂̏ꍇ");
@@ -294,6 +296,29 @@ public class StringConcatenatorTest extends FunctionTester
     }
   }
 
+  public void repeat_repeatedStr_count()
+  {
+    MSG("ʏ̏ꍇ");
+    EQUAL(StringConcatenator.repeat("a", 0), "");
+    EQUAL(StringConcatenator.repeat("a", 1), "a");
+    EQUAL(StringConcatenator.repeat("a", 2), "aa");
+    EQUAL(StringConcatenator.repeat("a", 3), "aaa");
+    EQUAL(StringConcatenator.repeat("a", 4), "aaaa");
+  }
+
+  public void repeat_repeatedStr_count_1()
+  {
+    MSG("Jԉ񐔂̏ꍇ");
+    try {
+      StringConcatenator.repeat("a", -1);
+      NG();
+    } catch (AssertionError e) {
+      OK(e);
+    } catch (Exception e) {
+      NG(e);
+    }
+  }
+
   public void repeat_repeated_count_delimiter()
   {
     MSG("ʏ̏ꍇ");
@@ -695,6 +720,7 @@ public class StringConcatenatorTest extends FunctionTester
     EQUAL(StringConcatenator.concatenate(intL, mf, ","), "");
   }
 
+  @Deprecated
   public void concatenate_strings_delim_escape()
   {
     MSG("ʏ̏ꍇ");
@@ -705,6 +731,7 @@ public class StringConcatenatorTest extends FunctionTester
     EQUAL(StringConcatenator.concatenate(a, ',', '$'), "!#$$%&'(),=-~^|\\");
   }
 
+  @Deprecated
   public void concatenate_strings_delim_escape_1()
   {
     MSG("k̏ꍇ");
@@ -719,6 +746,7 @@ public class StringConcatenatorTest extends FunctionTester
     }
   }
 
+  @Deprecated
   public void concatenate_strings_delim_escape_2()
   {
     MSG("z̃TCY[̏ꍇ");
@@ -727,6 +755,39 @@ public class StringConcatenatorTest extends FunctionTester
     EQUAL(StringConcatenator.concatenate(a, ',', '$'), "");
   }
 
+  public void concatenate_strings_delimStr_escapeStr()
+  {
+    MSG("ʏ̏ꍇ");
+
+    String[] a = { "!#$%&'()", "=-~^|\\" };
+    EQUAL(StringConcatenator.concatenate(a, ",", "@"), "!#$%&'(),=-~^|\\");
+    EQUAL(StringConcatenator.concatenate(a, "|", "@"), "!#$%&'()|=-~^@|\\");
+    EQUAL(StringConcatenator.concatenate(a, ",", "$"), "!#$$%&'(),=-~^|\\");
+  }
+
+  public void concatenate_strings_delimStr_escapeStr_1()
+  {
+    MSG("k̏ꍇ");
+
+    try {
+      StringConcatenator.concatenate((String[])null, ",", "\\");
+      NG();
+    } catch (AssertionError e) {
+      OK(e);
+    } catch (Exception e) {
+      NG(e);
+    }
+  }
+
+  public void concatenate_strings_delimStr_escapeStr_2()
+  {
+    MSG("z̃TCY[̏ꍇ");
+
+    String[] a = new String[0];
+    EQUAL(StringConcatenator.concatenate(a, ",", "$"), "");
+  }
+
+  @Deprecated
   public void concatenate_enm_delim_escape()
   {
     MSG("ʏ̏ꍇ");
@@ -742,6 +803,7 @@ public class StringConcatenatorTest extends FunctionTester
     EQUAL(StringConcatenator.concatenate(e, ',', '$'), "!#$$%&'(),=-~^|\\");
   }
 
+  @Deprecated
   public void concatenate_enm_delim_escape_1()
   {
     MSG("k̏ꍇ");
@@ -757,6 +819,7 @@ public class StringConcatenatorTest extends FunctionTester
     }
   }
 
+  @Deprecated
   public void concatenate_enm_delim_escape_2()
   {
     MSG("vf[̏ꍇ");
@@ -766,6 +829,46 @@ public class StringConcatenatorTest extends FunctionTester
     EQUAL(StringConcatenator.concatenate(e, ',', '@'), "");
   }
 
+  public void concatenate_enm_delimStr_escapeStr()
+  {
+    MSG("ʏ̏ꍇ");
+
+    List<String> sL = new ArrayList<String>();
+    sL.add("!#$%&'()");
+    sL.add("=-~^|\\");
+    Enumeration<String> e = Collections.enumeration(sL);
+    EQUAL(StringConcatenator.concatenate(e, ",", "@"), "!#$%&'(),=-~^|\\");
+    e = Collections.enumeration(sL);
+    EQUAL(StringConcatenator.concatenate(e, "|", "@"), "!#$%&'()|=-~^@|\\");
+    e = Collections.enumeration(sL);
+    EQUAL(StringConcatenator.concatenate(e, ",", "$"), "!#$$%&'(),=-~^|\\");
+  }
+
+  public void concatenate_enm_delimStr_escapeStr_1()
+  {
+    MSG("k̏ꍇ");
+
+    try {
+      StringConcatenator.concatenate(
+        (Enumeration<String>)null, ",", "\\");
+      NG();
+    } catch (AssertionError e) {
+      OK(e);
+    } catch (Exception e) {
+      NG(e);
+    }
+  }
+
+  public void concatenate_enm_delimStr_escapeStr_2()
+  {
+    MSG("vf[̏ꍇ");
+
+    List<String> sL = new ArrayList<String>();
+    Enumeration<String> e = Collections.enumeration(sL);
+    EQUAL(StringConcatenator.concatenate(e, ",", "@"), "");
+  }
+
+  @Deprecated
   public void concatenate_coll_delim_escape()
   {
     MSG("ʏ̏ꍇ");
@@ -778,6 +881,7 @@ public class StringConcatenatorTest extends FunctionTester
     EQUAL(StringConcatenator.concatenate(c, ',', '$'), "!#$$%&'(),=-~^|\\");
   }
 
+  @Deprecated
   public void concatenate_coll_delim_escape_1()
   {
     MSG("k̏ꍇ");
@@ -792,6 +896,7 @@ public class StringConcatenatorTest extends FunctionTester
     }
   }
 
+  @Deprecated
   public void concatenate_coll_delim_escape_2()
   {
     MSG("vf[̏ꍇ");
@@ -800,6 +905,41 @@ public class StringConcatenatorTest extends FunctionTester
     EQUAL(StringConcatenator.concatenate(c, ',', '@'), "");
   }
 
+  public void concatenate_coll_delimStr_escapeStr()
+  {
+    MSG("ʏ̏ꍇ");
+
+    List<String> c = new ArrayList<String>();
+    c.add("!#$%&'()");
+    c.add("=-~^|\\");
+    EQUAL(StringConcatenator.concatenate(c, ",", "@"), "!#$%&'(),=-~^|\\");
+    EQUAL(StringConcatenator.concatenate(c, "|", "@"), "!#$%&'()|=-~^@|\\");
+    EQUAL(StringConcatenator.concatenate(c, ",", "$"), "!#$$%&'(),=-~^|\\");
+  }
+
+  public void concatenate_coll_delimStr_escapeStr_1()
+  {
+    MSG("k̏ꍇ");
+
+    try {
+      StringConcatenator.concatenate((Collection<String>) null, ",", "\\");
+      NG();
+    } catch (AssertionError e) {
+      OK(e);
+    } catch (Exception e) {
+      NG(e);
+    }
+  }
+
+  public void concatenate_coll_delimStr_escapeStr_2()
+  {
+    MSG("vf[̏ꍇ");
+
+    List<String> c = new ArrayList<String>();
+    EQUAL(StringConcatenator.concatenate(c, ",", "@"), "");
+  }
+
+  @Deprecated
   public void concatenate_strings_delim_openPar_closePar_escape()
   {
     MSG("ʏ̏ꍇ");
@@ -813,6 +953,7 @@ public class StringConcatenatorTest extends FunctionTester
       "/!#$$%&'()/,/=-~^|\\/");
   }
 
+  @Deprecated
   public void concatenate_strings_delim_openPar_closePar_escape_1()
   {
     MSG("k̏ꍇ");
@@ -827,6 +968,7 @@ public class StringConcatenatorTest extends FunctionTester
     }
   }
 
+  @Deprecated
   public void concatenate_strings_delim_openPar_closePar_escape_2()
   {
     MSG("vf[̏ꍇ");
@@ -835,6 +977,42 @@ public class StringConcatenatorTest extends FunctionTester
     EQUAL(StringConcatenator.concatenate(a, ',', '(', ')', '$'), "");
   }
 
+  public void concatenate_strings_delimStr_openPar_closePar_escapeStr()
+  {
+    MSG("ʏ̏ꍇ");
+
+    String[] a = { "!#$%&'()", "=-~^|\\" };
+    EQUAL(StringConcatenator.concatenate(a, ",", "[", "]", "@"),
+      "[!#$%&'()],[=-~^|\\]");
+    EQUAL(StringConcatenator.concatenate(a, "|", "(",")", "@"),
+      "(!#$%&'@(@))|(=-~^@|\\)");
+    EQUAL(StringConcatenator.concatenate(a, ",", "/", "/", "$"),
+      "/!#$$%&'()/,/=-~^|\\/");
+  }
+
+  public void concatenate_strings_delimStr_openPar_closePar_escapeStr_1()
+  {
+    MSG("k̏ꍇ");
+
+    try {
+      StringConcatenator.concatenate((String[])null, ",", "(", ")", "\\");
+      NG();
+    } catch (AssertionError e) {
+      OK(e);
+    } catch (Exception e) {
+      NG(e);
+    }
+  }
+
+  public void concatenate_strings_delimStr_openPar_closePar_escapeStr_2()
+  {
+    MSG("vf[̏ꍇ");
+
+    String[] a = new String[0];
+    EQUAL(StringConcatenator.concatenate(a, ",", "(", ")", "$"), "");
+  }
+
+  @Deprecated
   public void concatenate_enm_delim_openPar_closePar_escape()
   {
     MSG("ʏ̑");
@@ -856,6 +1034,7 @@ public class StringConcatenatorTest extends FunctionTester
       "/!#$$%&'()/,/=-~^|\\/");
   }
 
+  @Deprecated
   public void concatenate_enm_delim_openPar_closePar_escape_1()
   {
     MSG("k̏ꍇ");
@@ -871,6 +1050,7 @@ public class StringConcatenatorTest extends FunctionTester
     }
   }
 
+  @Deprecated
   public void concatenate_enm_delim_openPar_closePar_escape_2()
   {
     MSG("vf[̏ꍇ");
@@ -880,6 +1060,53 @@ public class StringConcatenatorTest extends FunctionTester
     EQUAL(StringConcatenator.concatenate(e, ',', '[', ']', '@'), "");
   }
 
+
+  public void concatenate_enm_delimStr_openPar_closePar_escapeStr()
+  {
+    MSG("ʏ̑");
+
+    List<String> c = new ArrayList<String>();
+    c.add("!#$%&'()");
+    c.add("=-~^|\\");
+
+    Enumeration<String> e = Collections.enumeration(c);
+    EQUAL(StringConcatenator.concatenate(e, ",", "[", "]", "@"),
+      "[!#$%&'()],[=-~^|\\]");
+
+    e = Collections.enumeration(c);
+    EQUAL(StringConcatenator.concatenate(e, "|", "(",")", "@"),
+      "(!#$%&'@(@))|(=-~^@|\\)");
+
+    e = Collections.enumeration(c);
+    EQUAL(StringConcatenator.concatenate(e, ",", "/", "/", "$"),
+      "/!#$$%&'()/,/=-~^|\\/");
+  }
+
+  public void concatenate_enm_delimStr_openPar_closePar_escapeStr_1()
+  {
+    MSG("k̏ꍇ");
+
+    try {
+      StringConcatenator.concatenate(
+        (Enumeration<String>) null, ",","(",")","@");
+      NG();
+    } catch (AssertionError e) {
+      OK(e);
+    } catch (Exception e) {
+      NG(e);
+    }
+  }
+
+  public void concatenate_enm_delimStr_openPar_closePar_escapeStr_2()
+  {
+    MSG("vf[̏ꍇ");
+
+    List<String> c = new ArrayList<String>();
+    Enumeration<String> e = Collections.enumeration(c);
+    EQUAL(StringConcatenator.concatenate(e, ",", "[", "]", "@"), "");
+  }
+
+  @Deprecated
   public void concatenate_coll_delim_openPar_closePar_escape()
   {
     MSG("ʏ̏ꍇ");
@@ -898,6 +1125,7 @@ public class StringConcatenatorTest extends FunctionTester
       "/!#$$%&'()/,/=-~^|\\/");
   }
 
+  @Deprecated
   public void concatenate_coll_delim_openPar_closePar_escape_1()
   {
     MSG("k̏ꍇ");
@@ -913,6 +1141,7 @@ public class StringConcatenatorTest extends FunctionTester
     }
   }
 
+  @Deprecated
   public void concatenate_coll_delim_openPar_closePar_escape_2()
   {
     MSG("vf[̏ꍇ");
@@ -920,4 +1149,45 @@ public class StringConcatenatorTest extends FunctionTester
     List<String> c = new ArrayList<String>();
     EQUAL(StringConcatenator.concatenate(c, ',', '[', ']', '@'), "");
   }
+
+  public void concatenate_coll_delimStr_openPar_closePar_escapeStr()
+  {
+    MSG("ʏ̏ꍇ");
+
+    List<String> c = new ArrayList<String>();
+    c.add("!#$%&'()");
+    c.add("=-~^|\\");
+
+    EQUAL(StringConcatenator.concatenate(c, ",", "[", "]", "@"),
+      "[!#$%&'()],[=-~^|\\]");
+
+    EQUAL(StringConcatenator.concatenate(c, "|", "(",")", "@"),
+      "(!#$%&'@(@))|(=-~^@|\\)");
+
+    EQUAL(StringConcatenator.concatenate(c, ",", "/", "/", "$"),
+      "/!#$$%&'()/,/=-~^|\\/");
+  }
+
+  public void concatenate_coll_delimStr_openPar_closePar_escapeStr_1()
+  {
+    MSG("k̏ꍇ");
+
+    try {
+      StringConcatenator.concatenate((Collection<String>)
+        null, ",","(",")","@");
+      NG();
+    } catch (AssertionError e) {
+      OK(e);
+    } catch (Exception e) {
+      NG(e);
+    }
+  }
+
+  public void concatenate_coll_delimStr_openPar_closePar_escapeStr_2()
+  {
+    MSG("vf[̏ꍇ");
+
+    List<String> c = new ArrayList<String>();
+    EQUAL(StringConcatenator.concatenate(c, ",", "[", "]", "@"), "");
+  }
 }
